@@ -23,9 +23,32 @@
 #include <fmt/ostream.h>
 
 #include <miktex/Core/ConfigNames>
+#include <miktex/Core/CommandLineBuilder>
+
+#if defined(MIKTEX_TEXMF_SHARED)
+#  define C4PEXPORT MIKTEXDLLEXPORT
+#else
+#  define C4PEXPORT
+#endif
+#define C1F0C63F01D5114A90DDF8FC10FF410B
+#include "miktex/C4P/C4P.h"
+
+#if defined(MIKTEX_TEXMF_SHARED)
+#  define MIKTEXMFEXPORT MIKTEXDLLEXPORT
+#else
+#  define MIKTEXMFEXPORT
+#endif
+#define B8C7815676699B4EA2DE96F0BD727276
+#include "miktex/TeXAndFriends/WebAppInputLine.h"
 
 #include "internal.h"
 
+using namespace std;
+
+using namespace MiKTeX::Core;
+using namespace MiKTeX::Util;
+using namespace MiKTeX::TeXAndFriends;
+
 struct Bom
 {
 public:
@@ -159,81 +182,6 @@ bool WebAppInputLine::ProcessOption(int opt, const string& optArg)
   return WebApp::ProcessOption(opt, optArg);
 }
 
-#if defined(WITH_OMEGA)
-PathName WebAppInputLine::MangleNameOfFile(const char* lpszFrom)
-{
-  PathName ret;
-  char* lpszTo = ret.GetData();
-  MIKTEX_ASSERT_STRING(lpszFrom);
-  size_t len = StrLen(lpszFrom);
-  if (len >= ret.GetCapacity())
-  {
-    MIKTEX_UNEXPECTED();
-  }
-  size_t idx;
-  for (idx = 0; idx < len; ++idx)
-  {
-    if (lpszFrom[idx] == ' ')
-    {
-      lpszTo[idx] = '*';
-    }
-    else if (lpszFrom[idx] == '~')
-    {
-      lpszTo[idx] = '?';
-    }
-    else if (lpszFrom[idx] == '\\')
-    {
-      lpszTo[idx] = '/';
-    }
-    else
-    {
-      lpszTo[idx] = lpszFrom[idx];
-    }
-  }
-  lpszTo[idx] = 0;
-  return ret;
-}
-#endif
-
-#if defined(WITH_OMEGA)
-template<typename CharType> static PathName UnmangleNameOfFile_(const CharType* lpszFrom)
-{
-  PathName ret;
-  char* lpszTo = ret.GetData();
-  MIKTEX_ASSERT_STRING(lpszFrom);
-  size_t len = StrLen(lpszFrom);
-  if (len >= ret.GetCapacity())
-  {
-    MIKTEX_UNEXPECTED();
-  }
-  size_t idx;
-  for (idx = 0; idx < len; ++idx)
-  {
-    if (lpszFrom[idx] == '*')
-    {
-      lpszTo[idx] = ' ';
-    }
-    else if (lpszFrom[idx] == '?')
-    {
-      lpszTo[idx] = '~';
-    }
-    else
-    {
-      lpszTo[idx] = lpszFrom[idx];
-    }
-  }
-  lpszTo[idx] = 0;
-  return ret;
-}
-#endif
-
-#if defined(WITH_OMEGA)
-PathName WebAppInputLine::UnmangleNameOfFile(const char* lpszFrom)
-{
-  return UnmangleNameOfFile_(lpszFrom);
-}
-#endif
-
 static bool IsOutputFile(const PathName& path)
 {
   PathName path_(path);
@@ -353,14 +301,6 @@ bool WebAppInputLine::OpenOutputFile(C4P::FileRoot& f, const PathName& fileName,
   }
   else
   {
-#if defined(WITH_OMEGA)
-    PathName unmangled;
-    if (AmI("omega"))
-    {
-      unmangled = UnmangleNameOfFile(lpszPath);
-      lpszPath = unmangled.GetData();
-    }
-#endif
     bool isAuxFile = !IsOutputFile(PathName(lpszPath));
     PathName path;
     if (isAuxFile && !pimpl->auxDirectory.Empty())
@@ -451,15 +391,6 @@ bool WebAppInputLine::OpenInputFile(FILE** ppFile, const PathName& fileName)
   }
   else
   {
-#if defined(WITH_OMEGA)
-    PathName unmangled;
-    if (AmI("omega"))
-    {
-      unmangled = UnmangleNameOfFile(lpszFileName);
-      lpszFileName = unmangled.GetData();
-    }
-#endif
-
     if (!session->FindFile(lpszFileName, GetInputFileType(), pimpl->foundFile))
     {
       return false;
@@ -547,18 +478,17 @@ bool WebAppInputLine::OpenInputFile(FILE** ppFile, const PathName& fileName)
 
 bool WebAppInputLine::OpenInputFile(C4P::FileRoot& f, const PathName& fileName)
 {
-  FILE* pFile = nullptr;
+  FILE* file = nullptr;
 
-  if (!OpenInputFile(&pFile, fileName))
+  if (!OpenInputFile(&file, fileName))
   {
     return false;
   }
 
-  f.Attach(pFile, true);
+  f.Attach(file, true);
 
 #if defined(PASCAL_TEXT_IO)
-  not_implemented();
-  get(f);
+  MIKTEX_UNIMPLEMENTED();
 #endif
 
   pimpl->lastInputFileName = fileName;
@@ -685,21 +615,7 @@ void WebAppInputLine::BufferSizeExceeded() const
   }
 }
 
-inline int GetCharacter(FILE* file)
-{
-  MIKTEX_ASSERT(file != nullptr);
-  int ch = getc(file);
-  if (ch == EOF)
-  {
-    if (ferror(file) != 0)
-    {
-      MIKTEX_FATAL_CRT_ERROR("getc");
-    }
-  }
-  return ch;
-}
-
-bool WebAppInputLine::InputLine(C4P_text& f, C4P_boolean bypassEndOfLine) const
+bool WebAppInputLine::InputLine(C4P::C4P_text& f, C4P::C4P_boolean bypassEndOfLine) const
 {
   f.AssertValid();
 
@@ -708,36 +624,17 @@ bool WebAppInputLine::InputLine(C4P_text& f, C4P_boolean bypassEndOfLine) const
     MIKTEX_UNEXPECTED();
   }
 
-#if defined(PASCAL_TEXT_IO)
-  MIKTEX_UNEXPECTED();
-#endif
+  MIKTEX_EXPECT(!f.IsPascalFileIO());
 
   IInputOutput* inputOutput = GetInputOutput();
 
-  const C4P_signed32 first = inputOutput->first();
-  C4P_signed32& last = inputOutput->last();
-  C4P_signed32 bufsize = inputOutput->bufsize();
+  const C4P::C4P_signed32 first = inputOutput->first();
+  C4P::C4P_signed32& last = inputOutput->last();
+  C4P::C4P_signed32 bufsize = inputOutput->bufsize();
 
-  const char* xord = nullptr;
-#if defined(WITH_OMEGA)
-  if (!AmI("omega"))
-#endif
-  {
-    xord = GetCharacterConverter()->xord();
-  }
+  const char* xord = GetCharacterConverter()->xord();
 
-  char *buffer = nullptr;
-#if defined(WITH_OMEGA)
-  char16_t* buffer16 = nullptr;
-  if (AmI("omega"))
-  {
-    buffer16 = inputOutput->buffer16();
-  }
-  else
-#endif
-  {
-    buffer = inputOutput->buffer();
-  }
+  char *buffer = inputOutput->buffer();
 
   last = first;
 
@@ -746,14 +643,14 @@ bool WebAppInputLine::InputLine(C4P_text& f, C4P_boolean bypassEndOfLine) const
     return false;
   }
 
-  int ch = GetCharacter(f);
+  int ch = GetC(f);
   if (ch == EOF)
   {
     return false;
   }
   if (ch == '\r')
   {
-    ch = GetCharacter(f);
+    ch = GetC(f);
     if (ch == EOF)
     {
       return false;
@@ -770,32 +667,20 @@ bool WebAppInputLine::InputLine(C4P_text& f, C4P_boolean bypassEndOfLine) const
     return true;
   }
 
-#if defined(WITH_OMEGA)
-  if (AmI("omega"))
-  {
-    buffer16[last] = ch;
-  }
-  else
-#endif
-  {
-    buffer[last] = xord[ch & 0xff];
-  }
+  buffer[last] = xord[ch & 0xff];
   last += 1;
 
-  while ((ch = GetCharacter(f)) != EOF)
+  while ((ch = GetC(f)) != EOF)
   {
     if (last >= bufsize)
     {
       BufferSizeExceeded();
       bufsize = inputOutput->bufsize();
-#if defined(WITH_OMEGA)
-      if (!AmI("omega"))
-#endif
       buffer = inputOutput->buffer();
     }
     if (ch == '\r')
     {
-      ch = GetCharacter(f);
+      ch = GetC(f);
       if (ch == EOF)
       {
         break;
@@ -810,16 +695,7 @@ bool WebAppInputLine::InputLine(C4P_text& f, C4P_boolean bypassEndOfLine) const
     {
       break;
     }
-#if defined(WITH_OMEGA)
-    if (AmI("omega"))
-    {
-      buffer16[last] = ch;
-    }
-    else
-#endif
-    {
-      buffer[last] = xord[ch & 0xff];
-    }
+    buffer[last] = xord[ch & 0xff];
     last += 1;
   }
 
@@ -833,21 +709,9 @@ bool WebAppInputLine::InputLine(C4P_text& f, C4P_boolean bypassEndOfLine) const
     }
   }
 
-#if defined(WITH_OMEGA)
-  if (AmI("omega"))
+  while (last > first && (buffer[last - 1] == ' ' || buffer[last - 1] == '\r'))
   {
-    while (last > first && (buffer16[last - 1] == u' ' || buffer16[last - 1] == u'\r'))
-    {
-      last -= 1;
-    }
-  }
-  else
-#endif
-  {
-    while (last > first && (buffer[last - 1] == ' ' || buffer[last - 1] == '\r'))
-    {
-      last -= 1;
-    }
+    last -= 1;
   }
 
   return true;
