@@ -1,6 +1,6 @@
 /* This is dvipdfmx, an eXtended version of dvipdfm by Mark A. Wicks.
 
-    Copyright (C) 2002-2018 by Jin-Hwan Cho and Shunsaku Hirata,
+    Copyright (C) 2002-2020 by Jin-Hwan Cho and Shunsaku Hirata,
     the dvipdfmx project team.
 
     Copyright (C) 2012-2015 by Khaled Hosny <khaledhosny@eglug.org>
@@ -924,8 +924,15 @@ dvi_locate_font (const char *tfm_name, spt_t ptsize)
         WARN(">> Please check if kpathsea library can find this font: %s", mrec1->font_name);
       }
     } else if (mrec && !mrec->map_name) {
-      WARN(">> This font is mapped to a physical font \"%s\".", mrec->font_name);
-      WARN(">> Please check if kpathsea library can find this font: %s", mrec->font_name);
+      char *finaldot = strrchr(mrec->font_name, '.');
+      if (finaldot && strcasecmp(finaldot, ".pfa") == 0) {
+        /* type1 fonts with pfa format are not supported */
+        WARN("This font is mapped to a physical font \"%s\".", mrec->font_name);
+        ERROR("Sorry, pfa format not supported; please convert the font to pfb, e.g., with t1binary.");
+      } else {
+        WARN(">> This font is mapped to a physical font \"%s\".", mrec->font_name);
+        WARN(">> Please check if kpathsea library can find this font: %s", mrec->font_name);
+      }
     } else {
       WARN(">> There are no valid font mapping entry for this font.");
       WARN(">> Font file name \"%s\" was assumed but failed to locate that font.", tfm_name);
@@ -2255,6 +2262,8 @@ read_length (double *vp, double mag, const char **pp, const char *endptr)
   return  error;
 }
 
+#include "pdfencrypt.h"
+
 static int
 scan_special_encrypt (int *key_bits, int32_t *permission, char *opassword, char *upassword,
                       const char **curptr, const char *endptr)
@@ -2275,15 +2284,23 @@ scan_special_encrypt (int *key_bits, int32_t *permission, char *opassword, char
       skip_white(&p, endptr);
       if (!strcmp(kp, "ownerpw")) {
         if ((obj = parse_pdf_string(&p, endptr))) {
-          if (pdf_string_value(obj))
-            strncpy(opassword, pdf_string_value(obj), sizeof(opassword)-1);
+          if (pdf_string_value(obj)) {
+            int str_length = (MAX_PWD_LEN - 1 > pdf_string_length(obj)
+                ? pdf_string_length(obj) : MAX_PWD_LEN - 1);
+            strncpy(opassword, pdf_string_value(obj), str_length);
+            opassword[str_length] = '\0';
+          }
           pdf_release_obj(obj);
         } else
           error = -1;
       } else if (!strcmp(kp, "userpw")) {
         if ((obj = parse_pdf_string(&p, endptr))) {
-          if (pdf_string_value(obj))
-            strncpy(upassword, pdf_string_value(obj), sizeof(upassword)-1);
+          if (pdf_string_value(obj)) {
+            int str_length = (MAX_PWD_LEN - 1 > pdf_string_length(obj)
+                ? pdf_string_length(obj) : MAX_PWD_LEN - 1);
+            strncpy(upassword, pdf_string_value(obj), str_length);
+            upassword[str_length] = '\0';
+          }
           pdf_release_obj(obj);
         } else
           error = -1;
