@@ -36,8 +36,8 @@
 #include <miktex/Core/DirectoryLister>
 #include <miktex/Core/File>
 #if defined(MIKTEX_WINDOWS)
-#include <miktex/Util/CharBuffer>
-#define UW_(x) MiKTeX::Util::CharBuffer<wchar_t>(x).GetData()
+#include <miktex/Util/PathNameUtil>
+#define EXPATH_(x) MiKTeX::Util::PathNameUtil::ToLengthExtendedPathName(x)
 #endif
 #endif
 
@@ -117,8 +117,8 @@ bool FileSystem::remove (const string &fname) {
  *  @return true on success */
 bool FileSystem::copy (const string &src, const string &dest, bool remove_src) {
 #if defined(MIKTEX_WINDOWS)
-        ifstream ifs(UW_(src), ios::in | ios::binary);
-        ofstream ofs(UW_(dest), ios::out | ios::binary);
+        ifstream ifs(EXPATH_(src), ios::in | ios::binary);
+        ofstream ofs(EXPATH_(dest), ios::out | ios::binary);
 #else
 	ifstream ifs(src, ios::in|ios::binary);
 	ofstream ofs(dest, ios::out|ios::binary);
@@ -152,7 +152,7 @@ uint64_t FileSystem::filesize (const string &fname) {
 	// so we have to use this freaky code
 	WIN32_FILE_ATTRIBUTE_DATA attr;
 #if defined(MIKTEX)
-        GetFileAttributesExW(UW_(fname.c_str()), GetFileExInfoStandard, &attr);
+        GetFileAttributesExW(EXPATH_(fname).c_str(), GetFileExInfoStandard, &attr);
 #else
 	GetFileAttributesExA(fname.c_str(), GetFileExInfoStandard, &attr);
 #endif
@@ -296,7 +296,7 @@ bool FileSystem::rmdir (const string &dirname) {
 	if (isDirectory(dirname)) {
 		ok = true;
 #if defined(MIKTEX)
-                MiKTeX::Core::Directory::Delete(dirname, true);
+                MiKTeX::Core::Directory::Delete(MiKTeX::Core::PathName(dirname), true);
 #else
 #ifdef _WIN32
 		string pattern = dirname + "/*";
@@ -347,7 +347,7 @@ bool FileSystem::exists (const string &fname) {
 	if (const char *cfname = fname.c_str()) {
 
 #if defined(MIKTEX)
-                return MiKTeX::Core::File::Exists(fname) || MiKTeX::Core::Directory::Exists(fname);
+                return MiKTeX::Core::File::Exists(MiKTeX::Core::PathName(fname)) || MiKTeX::Core::Directory::Exists(MiKTeX::Core::PathName(fname));
 #else
 #ifdef _WIN32
 		return GetFileAttributes(cfname) != INVALID_FILE_ATTRIBUTES;
@@ -365,7 +365,7 @@ bool FileSystem::exists (const string &fname) {
 bool FileSystem::isDirectory (const string &fname) {
 	if (const char *cfname = fname.c_str()) {
 #if defined(MIKTEX)
-                return MiKTeX::Core::Directory::Exists(fname);
+                return MiKTeX::Core::Directory::Exists(MiKTeX::Core::PathName(fname));
 #else
 #ifdef _WIN32
 		auto attr = GetFileAttributes(cfname);
@@ -384,7 +384,7 @@ bool FileSystem::isDirectory (const string &fname) {
 bool FileSystem::isFile (const string &fname) {
 	if (const char *cfname = fname.c_str()) {
 #if defined(MIKTEX)
-                return MiKTeX::Core::File::Exists(fname);
+                return MiKTeX::Core::File::Exists(MiKTeX::Core::PathName(fname));
 #else
 #ifdef _WIN32
 		ifstream ifs(cfname);
@@ -402,13 +402,13 @@ bool FileSystem::isFile (const string &fname) {
 int FileSystem::collect (const std::string &dirname, vector<string> &entries) {
 	entries.clear();
 #if defined(MIKTEX)
-        unique_ptr<MiKTeX::Core::DirectoryLister> lister = MiKTeX::Core::DirectoryLister::Open(dirname);
+        unique_ptr<MiKTeX::Core::DirectoryLister> lister = MiKTeX::Core::DirectoryLister::Open(MiKTeX::Core::PathName(dirname));
         MiKTeX::Core::DirectoryEntry entry;
         while (lister->GetNext(entry))
         {
           MiKTeX::Core::PathName path(dirname);
           path /= entry.name;
-          string typechar = isFile(path.GetData()) ? "f" : isDirectory(path.GetData()) ? "d" : "?";
+          string typechar = isFile(path.ToString()) ? "f" : isDirectory(path.ToString()) ? "d" : "?";
           if (entry.name != "." && entry.name != "..")
           {
             entries.push_back(typechar + entry.name);
