@@ -35,6 +35,8 @@
 #endif
 #include <sys/types.h>
 
+#define GC_PTHREAD_SIGMASK_NEEDED
+
 #include "common.h"
 #if defined(MIKTEX)
 #  include <miktex/Core/Session>
@@ -49,7 +51,7 @@
 #include "settings.h"
 #include "locate.h"
 #include "interact.h"
-#include "process.h"
+#include "fileio.h"
 
 #include "stack.h"
 
@@ -60,7 +62,7 @@ using interact::interactive;
 namespace run {
 void purge();
 }
-  
+
 #ifdef PROFILE
 namespace vm {
 extern void dumpProfile();
@@ -84,11 +86,11 @@ int sigsegv_handler (void *, int emergency)
     cerr << "Stack overflow or segmentation fault: rerun with -nothreads"
          << endl;
   else
-#endif    
+#endif
     cerr << "Segmentation fault" << endl;
   abort();
 }
-#endif 
+#endif
 
 void setsignal(RETSIGTYPE (*handler)(int))
 {
@@ -120,7 +122,13 @@ void interruptHandler(int)
   em.Interrupt(true);
 }
 
-struct Args 
+bool hangup=false;
+void hangup_handler(int sig)
+{
+  hangup=true;
+}
+
+struct Args
 {
   int argc;
   char **argv;
@@ -130,7 +138,6 @@ struct Args
 void *asymain(void *A)
 {
   setsignal(signalHandler);
-  
   Args *args=(Args *) A;
   fpu_trap(trap());
 
@@ -142,12 +149,30 @@ void *asymain(void *A)
       doUnrestrictedList();
     } catch(handled_error) {
       em.statusError();
-    } 
+    }
   } else {
     int n=numArgs();
-    if(n == 0) 
-      processFile("-");
-    else
+    if(n == 0) {
+      int inpipe=intcast(settings::getSetting<Int>("inpipe"));
+      if(inpipe >= 0) {
+#if !defined(MIKTEX_WINDOWS)
+        // TODO
+        Signal(SIGHUP,hangup_handler);
+#endif
+        camp::openpipeout();
+        fprintf(camp::pipeout,"\n");
+        fflush(camp::pipeout);
+      }
+      while(true) {
+        processFile("-",true);
+        try {
+          setOptions(args->argc,args->argv);
+        } catch(handled_error) {
+          em.statusError();
+        }
+        if(inpipe < 0) break;
+      }
+    } else {
       for(int ind=0; ind < n; ind++) {
         processFile(string(getArg(ind)),n > 1);
         try {
@@ -155,8 +180,9 @@ void *asymain(void *A)
             setOptions(args->argc,args->argv);
         } catch(handled_error) {
           em.statusError();
-        } 
+        }
       }
+    }
   }
 
 #ifdef PROFILE
@@ -178,13 +204,13 @@ void *asymain(void *A)
     MiKTeX::Aymptote::exitRequested = true;
     gl::initSignal.notify_one();
 #else
-    pthread_kill(gl::mainthread,SIGUSR2);
+    pthread_kill(gl::mainthread,SIGURG);
     pthread_join(gl::mainthread,NULL);
 #endif
   }
 #endif
 #endif
-  exit(em.processStatus() || interact::interactive ? 0 : 1);  
+  exit(em.processStatus() || interact::interactive ? 0 : 1);
 }
 #if defined(MIKTEX)
 void BackgroundThread(void* ptr)
@@ -212,7 +238,7 @@ void exitHandler(int)
 #if defined(MIKTEX)
 int main(int argc, char** argv)
 #else
-int main(int argc, char *argv[]) 
+int main(int argc, char *argv[])
 #endif
 {
 #if defined(MIKTEX)
@@ -225,10 +251,10 @@ int main(int argc, char *argv[])
       << "         run 'mpm --install asymptote' to install it\n";
   }
 #endif
-#ifdef HAVE_LIBGSL  
+#ifdef HAVE_LIBGSL
   unsetenv("GSL_RNG_SEED");
   unsetenv("GSL_RNG_TYPE");
-#endif  
+#endif
   setsignal(signalHandler);
 
   try {
@@ -236,17 +262,17 @@ int main(int argc, char *argv[])
   } catch(handled_error) {
     em.statusError();
   }
-  
+
   Args args(argc,argv);
 #ifdef HAVE_GL
 #ifdef __APPLE__
   bool usethreads=true;
 #else
   bool usethreads=view();
-#endif  
+#endif
   gl::glthread=usethreads ? getSetting<bool>("threads") : false;
 #if HAVE_PTHREAD
-  
+
   if(gl::glthread) {
     pthread_t thread;
     try {
@@ -257,7 +283,7 @@ int main(int argc, char *argv[])
         sigaddset(&set, SIGCHLD);
         pthread_sigmask(SIG_BLOCK, &set, NULL);
         while(true) {
-          Signal(SIGUSR2,exitHandler);
+          Signal(SIGURG,exitHandler);
           camp::glrenderWrapper();
           gl::initialize=true;
         }
@@ -279,14 +305,21 @@ int main(int argc, char *argv[])
   }
 #endif
   gl::glthread=false;
-#endif  
+#endif
   asymain(&args);
 #if defined(MIKTEX)
   // MIKTEX-UNEXPECTED: unreachable code
   return 0;
 #endif
 }
+
+#ifdef USEGC
+GC_API void GC_CALL GC_throw_bad_alloc() {
+  std::bad_alloc();
+}
+#endif
 #if defined(MIKTEX)
 #include "types.h"
 const types::signature::OPEN_t types::signature::OPEN;
 #endif
+
