@@ -64,14 +64,6 @@ const struct poptOption IniTeXMFApp::options[] = {
     T_("CONFIGFILE")
   },
 
-  {
-    "csv", 0,
-    POPT_ARG_NONE | POPT_ARGFLAG_DOC_HIDDEN, nullptr,
-    OPT_CSV,
-    T_("Print comma-separated values."),
-    nullptr
-  },
-
   {
     "default-paper-size", 0,
     POPT_ARG_STRING, nullptr,
