@@ -21,6 +21,8 @@
 
 #include "config.h"
 
+#include "makefmt-version.h"
+
 #include <miktex/Core/ConfigNames>
 #include <miktex/Core/TemporaryDirectory>
 #include <miktex/Util/Tokenizer>
@@ -52,9 +54,6 @@ enum class Engine
   pdfTeX,
   XeTeX,
   LuaHBTeX,
-#if defined(WITH_OMEGA)
-  Omega,
-#endif
 };
 
 class PdfConfigValues :
@@ -135,12 +134,6 @@ private:
     {
       this->engine = Engine::LuaHBTeX;
     }
-#if defined(WITH_OMEGA)
-    else if (Utils::EqualsIgnoreCase(engine, "omega"))
-    {
-      this->engine = Engine::Omega;
-    }
-#endif
     else
     {
       FatalError(fmt::format(T_("Unknown engine: {0}"), engine));
@@ -168,10 +161,6 @@ public:
       return "xetex";
     case Engine::LuaHBTeX:
       return "luahbtex";
-#if defined(WITH_OMEGA)
-    case Engine::Omega:
-      return "omega";
-#endif
     }
     MIKTEX_UNEXPECTED();
   }
@@ -191,10 +180,6 @@ private:
       return MIKTEX_XETEX_EXE;
     case Engine::LuaHBTeX:
       return MIKTEX_LUAHBTEX_EXE;
-#if defined(WITH_OMEGA)
-    case Engine::Omega:
-      return MIKTEX_OMEGA_EXE;
-#endif
     }
     MIKTEX_UNEXPECTED();
   }
