@@ -1,4 +1,4 @@
-/* pdftex-version.h: version number                     -*- C++ -*-
+/* pdftex-version.h:
 
    Copyright (C) 1996-2020 Christian Schenk
 
@@ -19,18 +19,15 @@
 
 #include "pdftex_version.h"
 
-#define MIKTEX_COMP_J2000_VERSION 7439
+#define MIKTEX_COMP_MAJOR_VERSION 4
+#define MIKTEX_COMP_MINOR_VERSION 0
+#define MIKTEX_COMP_PATCH_VERSION 0
+
+
 #define MIKTEX_COMP_ORIG_VERSION_STR PDFTEX_VERSION
 
-#define MIKTEX_COMP_COPYRIGHT_STR "\
-Copyright (C) 1982 D. E. Knuth, \
-(C) 1996-2020 Han The Thanh"
+#define MIKTEX_COMP_COPYRIGHT_STR "© 1982 D. E. Knuth, © 1996-2020 Hàn Thế Thành"
 
-#define MIKTEX_COMP_COPYRIGHT_STR_1252 "\
- 1982 D. E. Knuth, \
- 1996-2020 Han The Thanh"
-
-#define MIKTEX_COMP_TM_STR "\
-TeX is a trademark of the American Mathematical Society."
+#define MIKTEX_COMP_TM_STR "TeX is a trademark of the American Mathematical Society."
 
 #include <miktex/Version>
